has_subcommand

Function has_subcommand 

pub fn has_subcommand(matches: &ArgMatches) -> bool
Returns true if a subcommand was selected.

This reads a parse result, so there has to be one: a root that rejects the line — because it requires arguments, or requires a subcommand — never gets this far. “Was this invocation naked?” is still Clap’s question to answer for such a root, by parsing the line again permissively (see App::parse_with_default_command in standout), never by reading the argument list by hand.