CommandContext

Struct CommandContext 

pub struct CommandContext {
    pub command_path: Vec<String>,
    pub extensions: Extensions,
}
Context passed to command handlers.

Provides information about the execution environment plus an extensions container for injecting custom state via pre-dispatch hooks.

Note that output format is deliberately not included here - format decisions are made by the render handler, not by logic handlers.

Extensions

Pre-dispatch hooks can inject state into extensions that handlers retrieve:

use standout_dispatch::{Hooks, HookError, CommandContext};

struct Database { /* ... */ }

let hooks = Hooks::new()
    .pre_dispatch(|_matches, ctx| {
        ctx.extensions.insert(Database { /* ... */ });
        Ok(())
    });

// In handler:
fn my_handler(matches: &clap::ArgMatches, ctx: &CommandContext) -> anyhow::Result<()> {
    let db = ctx.extensions.get_required::<Database>()?;
    // use db...
    Ok(())
}

Fields

command_path: Vec<String>

The command path being executed (e.g., [“config”, “get”])

extensions: Extensions

Type-safe container for custom state injection.

Pre-dispatch hooks can insert values that handlers retrieve.